/*
 * Copyright (C) 2017 zeoflow
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.zeoflow.memo.annotation;

import java.lang.annotation.Documented;
import java.lang.annotation.Retention;
import java.lang.annotation.Target;

import static java.lang.annotation.ElementType.FIELD;
import static java.lang.annotation.RetentionPolicy.CLASS;

/**
 * Marks a field as an SharedPreference key. This field will be mapped as the SharedPreference key
 * with Upper camel case.
 */
@Documented
@Target(FIELD)
@Retention(CLASS)
public @interface KeyName
{

    /**
     * Preference Key name value in the SharedPreference. If not used, defaults to the field value
     * with Upper camel case.
     *
     * @return The preference key name value of the SharedPreference.
     */
    String value();

}
